<?php

namespace App\Http\Livewire\Admin;

use App\Models\Category;
use App\Models\Subcategory;
use Livewire\Component;
use Illuminate\Support\Str;

class AdminAddCategoryComponent extends Component
{
    public $name;
    public $slug;
    public $category_id;
    
    public function generateSlug()
    {
        $this->slug = Str::slug($this->name);
    }

    public function updated($fields)
    {
        $this->validateOnly($fields, [
            'name' => 'required',
            'slug' => 'required|unique:categories',
            'category_id' => 'nullable|exists:categories,id'
        ]);
    }

    public function storeCategory()
    {
        $validatedData = $this->validate([
            'name' => 'required',
            'slug' => 'required|unique:categories',
            'category_id' => 'nullable|exists:categories,id'
        ]);

        // dd($validatedData);

        if($this->category_id){
            Subcategory::create($validatedData);
        }else{
            Category::create($validatedData);
        }

        

        $this->reset();
        
        session()->flash('message', 'Category has been created successfully');
    }

    public function render()
    {
        $categories = Category::all();
        return view('livewire.admin.admin-add-category-component', compact('categories'));
    }
}
