<?php

namespace App\Http\Livewire\Admin;

use Livewire\Component;
use App\Models\Coupon;
use Illuminate\Validation\Rule;

class AdminAddCouponComponent extends Component
{
    public $code;
    public $type;
    public $value;
    public $cart_value;
    public $expiry_date;
    public $date;

    public function updated($fields)
    {
        $this->validateOnly($fields, [
            'code' => ['required', 'string', 'unique:coupons'],
            'type' => ['required', Rule::in(Coupon::TYPES)],
            'value' => ['required', 'numeric'],
            'cart_value' => ['required', 'numeric'],
            'expiry_date' => ['required', 'date', "after_or_equal:$this->date"]
        ]);
    }
    
    public function createCoupon()
    {
        // dd($this->expiry_date);
        $validated = $this->validate([
            'code' => ['required', 'string', 'unique:coupons'],
            'type' => ['required', Rule::in(Coupon::TYPES)],
            'value' => ['required', 'numeric'],
            'cart_value' => ['required', 'numeric'],
            'expiry_date' => ['required', 'date', "after_or_equal:$this->date"]
        ]);

        Coupon::create($validated);

        session()->flash('message', 'Coupon has been created successfully');
    }

    public function render()
    {
        $this->date = date('Y/m/d');
        $types = Coupon::TYPES;
        return view('livewire.admin.admin-add-coupon-component', compact('types'));
    }
}
