<?php

namespace App\Http\Livewire\Admin;

use Livewire\Component;
use App\Models\Coupon;
use Illuminate\Validation\Rule;

class AdminEditCouponComponent extends Component
{
    public $coupon;
    public $coupon_id;
    public $code;
    public $type;
    public $value;
    public $cart_value;
    public $expiry_date;
    public $date;

    public function updated($fields)
    {
        $this->validateOnly($fields, [
            'code' => ['required', 'string', Rule::unique('coupons')->ignore($this->coupon_id)],
            'type' => ['required', Rule::in(Coupon::TYPES)],
            'value' => ['required', 'numeric'],
            'cart_value' => ['required', 'numeric'],
            'expiry_date' => ['required', 'date'],
        ]);
    }
    
    public function updateCoupon()
    {
        // dd($this->coupon);
        $validated = $this->validate([
            'code' => ['required', 'string',  Rule::unique('coupons')->ignore($this->coupon_id)],
            'type' => ['required', Rule::in(Coupon::TYPES)],
            'value' => ['required', 'numeric'],
            'cart_value' => ['required', 'numeric'],
            'expiry_date' => ['required', 'date']
        ]);

        $this->coupon->update($validated);

        session()->flash('message', 'Coupon has been updated successfully');
    }

    public function mount(Coupon $coupon)
    {
        $this->coupon = $coupon;
        $this->coupon_id = $coupon->id;
        $this->code = $coupon->code;
        $this->type = $coupon->type;
        $this->value = $coupon->value;
        $this->cart_value = $coupon->cart_value;
        $this->expiry_date = $coupon->expiry_date;
    }

    public function render()
    {
        $this->date = date('Y/m/d');
        $types = Coupon::TYPES;
        return view('livewire.admin.admin-edit-coupon-component', compact('types'));
    }
}
