<?php

namespace App\Http\Livewire\Admin;

use App\Models\Category;
use App\Models\Product;
use App\Models\Subcategory;
use Carbon\Carbon;
use Livewire\Component;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Livewire\WithFileUploads;
use Illuminate\Support\Facades\DB;

class AdminEditProductComponent extends Component
{
    use WithFileUploads;

    public $product;
    public $name;
    public $slug;
    public $short_description;
    public $description;
    public $regular_price;
    public $sale_price;
    public $SKU;
    public $stock_status;
    public $featured;
    public $quantity;
    public $image;
    public $newImage;
    public $category_id;
    public $subcategory_id;
    public $images;
    public $newImages;
    public $attr;
    // public $inputs = [];
    public $attr_arr = [];
    public $attr_values;

    protected $messages = [
        'SKU.required' => 'Enter an SKU for this item'
    ];

    public function mount(Product $product)
    {
        $this->product = $product;
        $this->name = $product->name;
        $this->slug = $product->slug;
        $this->short_description = $product->short_description;
        $this->description = $product->description;
        $this->regular_price = $product->regular_price;
        $this->sale_price = $product->sale_price;
        $this->SKU = $product->SKU;
        $this->quantity = $product->quantity;
        $this->image = $product->image;
        $this->images = explode(',', $product->images);
        $this->category_id = $product->category_id;
        $this->subcategory_id = $product->subcategory_id;
        $this->stock_status = $product->stock_status;
        $this->featured = $product->featured;
    }

    public function add()
    {       
        if(!in_array($this->attr, $this->attr_arr)){
            // array_push($this->inputs, $this->attr);
            array_push($this->attr_arr, $this->attr);
        }
    }

     public function remove($attr)
    {
        unset($this->attr_arr[$attr]);
    }

    public function generateSlug()
    {
        $this->slug = Str::slug($this->name);
    }

    public function updated($fields)
    {
        $this->validateOnly($fields, [
            "name" => 'required',
            "slug" => 'required|unique:products',
            "short_description" => 'required',
            "description" => 'required',
            "regular_price" => 'required|numeric',
            "sale_price" => 'nullable|numeric',
            "SKU" => 'required',
            "stock_status" => 'required',
            "featured" => 'required|boolean',
            "quantity" => 'required|numeric',
            "newImage" => 'nullable|image',
            "category_id" => 'required', 
            // "subcategory_id" => 'sometimes', 
        ]);
    }

    public function updateProduct()
    {
        $a = $this->validate([
            "name" => 'required',
            "slug" => ['required', Rule::unique('products')->ignore($this->product->id)],
            "short_description" => 'required',
            "description" => 'required',
            "regular_price" => 'required|numeric',
            "sale_price" => 'nullable|numeric',
            "SKU" => 'required',
            "stock_status" => 'required',
            "featured" => 'required|boolean',
            "quantity" => 'required|numeric',
            "newImage" => 'nullable|image',
            "category_id" => 'required', 
            // "subcategory_id" => 'sometimes', 
        ]);
        
        if($this->newImage){
            $imageName = Carbon::now()->timestamp . '.' . $this->newImage->extension();
            $this->newImage->storeAs('products', $imageName);
        }

         if($this->newImages){
            $imagesName = '';
            foreach($this->newImages as $key=>$image){
                $imgName = Carbon::now()->timestamp . $key . '.' . $this->image->extension();
                $image->storeAs('products', $imgName);
                $imagesName = $imagesName . ',' . $imgName;
            }

            if($this->images){
                $images = explode(",", $this->images );
                foreach ($images as $key=>$img) {
                    if($img){
                        unlink('assets/images/products/' . $img);
                    }
                }
            }
        }

        DB::beginTransaction();
        try{
            $this->product->update([
                'name' => $this->name,
                'slug' => $this->slug,
                'short_description' => $this->short_description,
                'description' => $this->description,
                'regular_price' => $this->regular_price,
                'sale_price' => $this->sale_price,
                'SKU' => $this->SKU,
                'stock_status' => $this->stock_status,
                'featured' => $this->featured,
                'quantity' => $this->quantity,
                'image' => $imageName ?? $this->image,
                'images' => $imagesName ? $imagesName : null,
                'category_id' => $this->category_id,
                'subcategory_id' => $this->subcategory_id ?? null,
            ]);

            if($this->image){
                unlink('assets/images/products/'. $this->image);
            }

            DB::commit();

            session()->flash('message', 'Product has been updated successfully');
        }catch(\Throwable $err){
            DB::rollBack();
            
            return redirect()->back()->with('error', "Post creation failed. {$err->getMessage()}");
        }
    }

    public function changeSubcategory(){
        $this->subcategory_id = 0;
    }

    public function render()
    {
         $statuses = [
                'in-stock' => 'In Stock' ,
                'out-of-stock' => 'Out of Stock'
        ];

        $categories = Category::all(); 
        $subcategories = Subcategory::where('category_id', $this->category_id)->get();
        return view('livewire.admin.admin-edit-product-component', compact('categories', 'subcategories', 'statuses'));
    }
}
