<?php

namespace App\Http\Livewire;

use Livewire\Component;
use App\Events\CartItemChangeEvent;
use App\Models\Coupon;
use App\Models\Sale;
use App\Traits\CartActions;
use App\Traits\SavedForLaterActions;
use Carbon\Carbon;
use Cart;
use Illuminate\Support\Facades\Auth;

class CartComponent extends Component
{
    use CartActions, SavedForLaterActions;

    public $haveCouponCode;
    public $couponCode;
    public $expiryDate;
    public $discount;
    public $subtotalAfterDiscount;
    public $taxAfterDiscount;
    public $totalAfterDiscount;

    public function applyCouponCode()
    {
        $time = date('Y/m/d');
        // $coupon = Coupon::where('code', $this->couponCode)
        //           ->where('expiry_date', '>=', Carbon::today())
        //           ->where('cart_value', '<=', Cart::instance('cart')->subtotal())
        //           ->first();
        $coupon = Coupon::where('code', $this->couponCode)
                ->first();

        if($coupon->expiry_date < Carbon::today())
        {
            session()->flash('coupon_error', 'Coupon code has expired');
            return;
        }

        if($coupon->cart_value > Cart::instance('cart')->subtotal())
        {
            session()->flash('coupon_error', 'Coupon code is invalid');
            return;
        }

        session()->put('coupon', [
            'code' => $coupon->code,
            'type' => $coupon->type,
            'value' => $coupon->value,
            'cart_value' => $coupon->cart_value
        ]);
    }

    public function calculateDiscounts()
    {
        if(session()->has('coupon')){
            if(session()->get('coupon')['type'] == 'fixed'){
                $this->discount = session()->get('coupon')['value'];
            }else{
                $this->discount = (Cart::instance('cart')->subtotal() * session()->get('coupon')['value'])/100;
            }
            $this->subtotalAfterDiscount = Cart::instance('cart')->subtotal() - $this->discount;
            $this->taxAfterDiscount = Round(($this->subtotalAfterDiscount * config('cart.tax'))/100, 2);
            $this->totalAfterDiscount = $this->subtotalAfterDiscount + $this->taxAfterDiscount;
        }
    }

    public function removeCoupon()
    {
        session()->forget('coupon');
    }

    public function checkout()
    {
        if(Auth::check()){
            return redirect()->route('checkout');
        }else{
            return redirect()->route('login');
        }
    }

    public function setAmountForCheckout()
    {
        if(!Cart::instance('cart')->count() > 0){
           session()->forget('checkout');
           return;
        }

        if(session()->has('coupon')){
            session()->put('checkout', [
                'discount' => $this->discount,
                'subtotal' => $this->subtotalAfterDiscount,
                'tax' => $this->taxAfterDiscount,
                'total' => $this->totalAfterDiscount
            ]);
        }else{
            session()->put('checkout', [
                'discount' => 0,
                'subtotal' => Cart::instance('cart')->subtotal(),
                'tax' => Cart::instance('cart')->tax(),
                'total' => Cart::instance('cart')->total(),
            ]);
        }
    }

    public function render()
    {  
        if(session()->has('coupon')){
            if(Cart::instance('cart')->subtotal() < session()->get('coupon')['cart_value']){
                session()->forget('coupon');
            }else{
                $this->calculateDiscounts();
            }
        }

        $this->setAmountForCheckout();
        
        $sale = Sale::find(1);
        // dd(Cart::instance('cart')->content());

        return view('livewire.cart-component', compact('sale'))->layout('layouts.base');
    }
}
