<?php

namespace App\Http\Livewire;

use App\Models\Product;
use Livewire\Component;
use Livewire\WithPagination;
use App\Models\Category;
use App\Models\Sale;
use App\Models\Subcategory;
use App\Traits\CartActions;
use App\Traits\SortOptions;
use Cart;

class CategoryComponent extends Component
{
    use WithPagination, SortOptions, CartActions;

    public $sorting;
    public $pagesize;
    public $category;
    public $subcategory;
    public $min_price;
    public $max_price;


    public function mount(Category $category, Subcategory $subcategory)
    {
        $this->sorting = "default";
        $this->pagesize = 12;
        $this->category = $category;
        $this->subcategory = $subcategory->exists ? $subcategory : null;

        $this->min_price = 1;
        $this->max_price = 1000;
    }
    
    public function render()
    {
        $products = $this->actions($this->sorting, $this->pagesize, $this->category->id, $this->subcategory?->id);

        $categories = Category::all();

        $popular_products = Product::inRandomOrder()->take(4)->get();

        $pageTitle = $this->category->name;

        $sale = Sale::find(1);

        $wishlist_ids = Cart::instance('wishlist')->content()->pluck('id');

        $cart_ids = Cart::instance('cart')->content()->pluck('id');

        return view('livewire.shop-component', compact('products', 'popular_products', 'categories', 'pageTitle', 'sale', 'wishlist_ids', 'cart_ids'));
    }
}
