<?php

namespace App\Http\Livewire;

use App\Models\Order;
use App\Models\OrderItem;
use App\Models\Shipping;
use App\Models\Transaction;
use Livewire\Component;
use Cart;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class CheckoutComponent extends Component
{
    public $ship_to_different = 0;

    public $firstname;
    public $lastname;
    public $email;
    public $mobile;
    public $address;
    public $city;
    public $country;
    public $zipcode;

    public $shipping_firstname;
    public $shipping_lastname;
    public $shipping_email;
    public $shipping_mobile;
    public $shipping_address;
    public $shipping_city;
    public $shipping_country;
    public $shipping_zipcode;

    public $payment_mode;
    public $thankyou;

    protected $messages = [
        'email.required' => 'The Email Address cannot be empty.',
        'email.email' => 'The Email Address format is not valid.',
        'shipping_firstname'  => 'The shipping firstname field is required when ship to different address is selected',
        'shipping_lastname.required_if' => 'The shipping lastname field is required when ship to different address is selected',
        'shipping_email.required_if'  => 'The shipping email field is required when ship to different address is selected',
        'shipping_mobile.required_if' => 'The shipping mobile number is required when ship to different address is selected',
        'shipping_address.required_if' => 'The shipping address field is required when ship to different address is selected',
        'shipping_city.required_if' => 'The shipping city field is required when ship to different address is selected',
        'shipping_country.required_if' => 'The shipping country field is required when ship to different address is selected',
        'shipping_zipcode.required_if' => 'The shipping zipcode field is required when ship to different address is selected',
    ];

    //['required_if:ship_to_different,1'],
    public function updated($fields)
    {
        // $this->validateOnly($fields, [
        //     'firstname'  => ['required'],
        //     'lastname' => ['required'],
        //     'email'  => ['required', 'email'],
        //     'mobile' => ['required', 'numeric', 'digits:11'],
        //     'address' => ['required'],
        //     'city' => ['required'],
        //     'country' => ['required'],
        //     'zipcode' => ['sometimes'],
        // ]);
        
        // if($this->ship_to_different){
        //     $this->validateOnly($fields, [
        //             'shipping_firstname'  => ['required'],
        //             'shipping_lastname' => ['required'],
        //             'shipping_email'  => ['required', 'email'],
        //             'shipping_mobile' => ['required', 'numeric', 'digits:11'],
        //             'shipping_address' => ['required'],
        //             'shipping_city' => ['required'],
        //             'shipping_country' => ['required'],
        //             'shipping_zipcode' => ['sometimes'],
        //             'payment_mode' => ['required']
        //         ]);
        // }

    }

    public function placeOrder()
    {
        // dd('yyyy');
        // dd($this->ship_to_different);
        $data =  $this->validate([
                    'firstname'  => ['required'],
                    'lastname' => ['required'],
                    'email'  => ['required', 'email'],
                    'mobile' => ['required', 'digits:11'],
                    'address' => ['required'],
                    'city' => ['required'],
                    'country' => ['required'],
                    'zipcode' => ['sometimes'],
                    'payment_mode' => ['required'],
                    'ship_to_different' => ['boolean'],
                    'shipping_firstname'  => ['required_if:ship_to_different,1'],
                    'shipping_lastname' => ['required_if:ship_to_different,1'],
                    'shipping_email'  => ['nullable','required_if:ship_to_different,1', 'email'],
                    'shipping_mobile' => ['nullable', 'required_if:ship_to_different,1', 'digits:11'],
                    'shipping_address' => ['required_if:ship_to_different,1'],
                    'shipping_city' => ['required_if:ship_to_different,1'],
                    'shipping_country' => ['required_if:ship_to_different,1'],
                    'shipping_zipcode' => ['sometimes'],
                ]);

        // dd($data);
        DB::beginTransaction();
        try{
                $order = new Order($data);
                $order->user_id = auth()->id();
                // dd(session()->get('checkout'));
                $order->subtotal = session()->get('checkout')['subtotal'];
                $order->discount = session()->get('checkout')['discount'];
                $order->tax = session()->get('checkout')['tax'];
                $order->total = session()->get('checkout')['total'];
                $order->status = 'ordered';
                $order->is_shipping_different = $this->ship_to_different ? 1 : 0;
                $order->save();

                foreach (Cart::instance('cart')->content() as $item) {
                    $orderItem = new OrderItem();
                    $orderItem->product_id = $item->id;
                    $orderItem->price = $item->price;
                    $orderItem->quantity = $item->qty;
                    
                    if($item->options){
                        // dd('here');
                        $orderItem->options = serialize($item->options);
                    }
                    $order->orderItems()->save($orderItem);
                }

                if($this->ship_to_different){
                    $s_data = [
                            'firstname'  => $this->shipping_firstname,
                            'lastname' => $this->shipping_lastname,
                            'email'  => $this->shipping_email,
                            'mobile' => $this->shipping_mobile,
                            'address' => $this->shipping_address,
                            'city' => $this->shipping_city,
                            'country' => $this->shipping_country,
                            'zipcode' => $this->shipping_zipcode,
                        ];

                    $shipping = new Shipping($s_data);
                    $order->shipping()->save($shipping);
                }

                if($this->payment_mode == 'cod'){
                    Transaction::create([
                        'user_id' => auth()->id(),
                        'order_id' => $order->id,
                        'mode' => 'cod',
                        'status' => 'pending'
                    ]);
                }

                $this->thankyou = 1;

                Cart::instance('cart')->destroy();

                session()->forget('checkout');

                DB::commit();

            } catch(\Throwable $err){

                DB::rollBack();
                
                return redirect()->back()->with('error', "Checkout failed. {$err->getMessage()}");
            }
        
    }

    public function verifyForCheckout()
    {
        if(!Auth::check()){
            return redirect()->route('login');
        }else if($this->thankyou){
            return redirect()->route('thankyou');
        }else if(!session()->get('checkout')){
            return redirect()->route('product.cart');
        }
    }

    public function render()
    {
        $this->verifyForCheckout();
        return view('livewire.checkout-component');
    }
}
