<?php

namespace App\Http\Livewire;

use App\Events\CartItemChangeEvent;
use Livewire\Component;
use App\Models\Product;
use App\Models\Sale;
use Cart;

class DetailsComponent extends Component
{
    public $product;
    public $quantity = 1;
    public $selAttribs = [];

    protected $listeners = [
        'incrementQty', 'decrementQty'
    ];

    public function incrementQty()
    {
        $this->quantity = $this->quantity + 1;
    }

    public function decrementQty()
    {
        $this->quantity = $this->quantity - 1;
    }

    public function addItem($id, $name, $price)
    {
        $this->addToCart($id, $name, $this->quantity, $price, $this->selAttribs);
    }

    public function addToCart($id, $name, $qty, $price, $attributes)
    {
        Cart::instance('cart')->add($id, $name, $qty, $price, $attributes)->associate('App\Models\Product');
        session()->flash('success_message', 'Item added to cart');
        return redirect()->route('cart');
    }

    public function mount(Product $product)
    {
        $this->product = $product;

        $attributes = $product->attributeValues->unique('attribute_id')->mapWithKeys(function($item){
            return [$item->attribute->id => $item->attribute->name];
       });
  
        foreach($attributes as $key => $attribute){
            $this->selAttribs[$attribute] = $product->attributeValues->where('attribute_id',  $key)->first()->value;
        };
    }

    public function render()
    {
        // dd($this->product->reviewedOrderItems);

        $galleryImages = explode(",", $this->product->images);
        $reviewedOrderItems = $this->product->reviewedOrderItems;
        $avgRating = $reviewedOrderItems->avg('review.rating');
        $popular_products = Product::inRandomOrder()->take(4)->get();
        $related_products = Product::where('category_id', $this->product->category_id)->inRandomOrder()->limit(5)->get();
        $sale = Sale::find(1);
        return view('livewire.details-component', compact('popular_products', 'related_products', 'sale', 'avgRating', 'reviewedOrderItems', 'galleryImages'));
    }
}
