<?php

namespace App\Http\Livewire;

use App\Models\Category;
use App\Models\HomeCategory;
use App\Models\HomeSlider;
use App\Models\Product;
use App\Models\Sale;
use Livewire\Component;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Cart;

class HomeComponent extends Component
{
    public function render()
    {
        $slides = HomeSlider::where('status', 1)->get();
        $latestProducts = Product::latest()->take(8)->get();
        $home_category = HomeCategory::find(1);
        $category_ids = $home_category->category_ids;
        $no_of_products = $home_category->no_of_products;
        $selected_categories = Category::with('products')->whereIn('id', $category_ids)->get()->map(function($category) use ($no_of_products) {
            $category->setRelation('products', $category->products->take($no_of_products));
            return $category;
        });

        $sale_products = Product::whereNotNull('sale_price')->inRandomOrder()->limit(8)->get();
        $sale = Sale::find(1);

        // dd(Carbon::parse($sale->sale_date)->format('Y/m/d h:m:s'));
        // dd($sale_products);
        if(Auth::check()){
            Cart::instance('cart')->restore(Auth::user()->email);
            Cart::instance('wishlist')->restore(Auth::user()->email);
            Cart::instance('savedForLater')->restore(Auth::user()->email);
        }

        
        return view('livewire.home-component', compact('slides', 'latestProducts', 'selected_categories', 'sale_products', 'sale'));
    }
}
