<?php

namespace App\Http\Livewire;

use App\Models\Product;
use Livewire\Component;
use Livewire\WithPagination;
use App\Models\Category;
use App\Models\Sale;
use App\Traits\CartActions;
use App\Traits\SortOptions;
use Cart;


class SearchComponent extends Component
{
    use WithPagination, SortOptions, CartActions;

    public $sorting;
    public $pagesize;
    public $min_price;
    public $max_price;
    public $search;
    public $product_cat;
    public $product_cat_id;

    public function mount()
    {
        $this->sorting = "default";
        $this->pagesize = 12;
        $this->fill(request()->only('search', 'product_cat', 'product_cat_id'));

        $this->min_price = 1;
        $this->max_price = 1000;
    }

    public function render()
    {
        $a = [
            $this->search, $this->product_cat, $this->product_cat_id
        ];

        // dd($a);
        
        $products = $this->actions($this->sorting, $this->pagesize,  $this->product_cat_id, null, $this->search);

        $categories = Category::all();

        $popular_products = Product::inRandomOrder()->take(4)->get();

        $pageTitle = 'Search Results';

        $sale = Sale::find(1);

        $wishlist_ids = Cart::instance('wishlist')->content()->pluck('id');

        $cart_ids = Cart::instance('cart')->content()->pluck('id');


        return view('livewire.search-component', compact('products', 'popular_products', 'categories', 'pageTitle',  'sale', 'wishlist_ids', 'cart_ids'));
    }
}
