<?php

namespace App\Http\Livewire;

use App\Models\Product;
use Livewire\Component;
use Livewire\WithPagination;
use App\Models\Category;
use App\Models\Sale;
use App\Traits\CartActions;
use App\Traits\SortOptions;
use App\Traits\WishlistActions;
use Illuminate\Support\Facades\Auth;
use Cart;


class ShopComponent extends Component
{
    use WithPagination, SortOptions, CartActions, WishlistActions;

    public $sorting;
    public $pagesize;
    public $min_price;
    public $max_price;

    public function mount()
    {
        $this->sorting = "default";
        $this->pagesize = 12;

        $this->min_price = 1;
        $this->max_price = 1000;
    }

    public function render()
    {
        // dd(Cart::instance('wishlist')->content());
        $products = $this->actions($this->sorting, $this->pagesize);

        $categories = Category::all();

        $popular_products = Product::inRandomOrder()->take(4)->get();

        $pageTitle = 'Shop';

        $sale = Sale::find(1);

        $wishlist_ids = Cart::instance('wishlist')->content()->pluck('id');

        $cart_ids = Cart::instance('cart')->content()->pluck('id');

        return view('livewire.shop-component', compact('products', 'popular_products', 'categories', 'pageTitle', 'sale', 'wishlist_ids', 'cart_ids'));
    }
}
