<?php

namespace App\Models;

use App\Traits\AdjustTime;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class OrderItem extends Model
{
    use HasFactory, AdjustTime;

    protected $fillable = [
        'product_id', 'order_id', 'price', 
        'quantity', 'review_status'
    ];

    protected $with = ['review'];

    public function order(): BelongsTo
    {
        return $this->belongsTo(Order::class);
    }

    public function product(): BelongsTo
    {
        return $this->belongsTo(Product::class);
    }

    public function review()
    {
        return $this->hasOne(Review::class, 'order_item_id');
    }

    public function scopeReviewed($query)
    {
        return $query->where('review_status', true);
    }
}
