<?php

namespace App\Models;

use App\Traits\HasMoney;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
// use NumberFormatter;

class Product extends Model
{
    use HasFactory, HasMoney;

    protected $fillable = [
        'name', 'slug', 'short_description', 'description',
        'regular_price', 'sale_price', 'SKU', 'stock_status',
        'featured', 'quantity', 'image', 'images', 
        'category_id', 'subcategory_id'
    ];

    protected $with = ['attributeValues'];

    const STATUS = ['in-stock', 'out-of-stock'];

    public function category()
    {
       return $this->belongsTo(Category::class);
    }

    public function format_regular_price()
    {
        return $this->formatCurrency($this->regular_price);
        // return str_replace(".00","", $money);
    }

    public function format_sale_price()
    {
        return $this->formatCurrency($this->sale_price);
    }

    public function getSalePriceAttribute()
    {
        return $this->attributes['sale_price'] > 0 ? $this->attributes['sale_price'] : null;
    }

    public function name()
    {
        return ucwords($this->name);
    }
    
    public function getRouteKeyName()
    {
        return 'slug';
    }

    public function subcategories()
    {
        return $this->belongsTo(Subcategory::class);
    }

    public function orderItems()
    {
        return $this->hasMany(OrderItem::class);
    }

    public function reviewedOrderItems()
    {
        return $this->orderItems()->reviewed();
    }

    public function attributeValues()
    {
        return $this->hasMany(AttributeValue::class);
    }
}
